==> haskell-insert-ordered-containers-0.2.5.3-99-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-insert-ordered-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 insert-ordered-containers
version:              0.2.5.3
visibility:           public
id:                   insert-ordered-containers-0.2.5.3-ApA7IiSvYfQBy1aFQSVAu8
key:                  insert-ordered-containers-0.2.5.3-ApA7IiSvYfQBy1aFQSVAu8
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/insert-ordered-containers#readme
synopsis:
    Associative containers retaining insertion order for traversals.

description:
    Associative containers retaining insertion order for traversals.

    The implementation is based on `unordered-containers`.

category:             Web
abi:                  20b9d4c963ee56d1101cd063b7f72885
exposed:              True
exposed-modules:      Data.HashMap.Strict.InsOrd Data.HashSet.InsOrd
hidden-modules:       Data.HashMap.InsOrd.Internal
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/insert-ordered-containers-0.2.5.3

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/insert-ordered-containers-0.2.5.3

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/insert-ordered-containers-0.2.5.3

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-insert-ordered-containers
hs-libraries:         HSinsert-ordered-containers-0.2.5.3-ApA7IiSvYfQBy1aFQSVAu8
depends:
    aeson-2.1.2.1-CJUEk8Q0QXZ63rfmeHQCzY base-4.17.2.1 deepseq-1.4.8.0
    hashable-1.4.4.0-LtdCyz5lRpSEDVfQGtCbHQ
    indexed-traversable-0.1.4-27X1GIy3K3S4C3KcOpuvZH
    lens-5.2.3-7QGQofAPyKYFc2G6dgdqBs
    optics-core-0.4.1.1-HhksGdGXui05lp1OU3YwkH
    optics-extra-0.4.2.1-5kg1YEIfjM248UVsPUgIdy
    semigroupoids-6.0.1-KVoagb3crffLRdR9EQjlIH text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-4tF6VC1d0ODJ0H7AFNioZw

haddock-interfaces:
    /usr/share/doc/haskell-insert-ordered-containers/html/insert-ordered-containers.haddock

haddock-html:         /usr/share/doc/haskell-insert-ordered-containers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-insert-ordered-containers-0.2.5.3-103-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-insert-ordered-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 insert-ordered-containers
version:              0.2.5.3
visibility:           public
id:                   insert-ordered-containers-0.2.5.3-Cxns96RKzfQ4jTFnCUhaPC
key:                  insert-ordered-containers-0.2.5.3-Cxns96RKzfQ4jTFnCUhaPC
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/insert-ordered-containers#readme
synopsis:
    Associative containers retaining insertion order for traversals.

description:
    Associative containers retaining insertion order for traversals.

    The implementation is based on `unordered-containers`.

category:             Web
abi:                  2d08596c6ac69730053c2a033a658c77
exposed:              True
exposed-modules:      Data.HashMap.Strict.InsOrd Data.HashSet.InsOrd
hidden-modules:       Data.HashMap.InsOrd.Internal
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/insert-ordered-containers-0.2.5.3

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/insert-ordered-containers-0.2.5.3

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/insert-ordered-containers-0.2.5.3

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-insert-ordered-containers
hs-libraries:         HSinsert-ordered-containers-0.2.5.3-Cxns96RKzfQ4jTFnCUhaPC
depends:
    aeson-2.1.2.1-GOr0sGsn8HVJzt9KhewtB0 base-4.17.2.1 deepseq-1.4.8.0
    hashable-1.4.4.0-HA5jWeGkLE053htWZjUgjX
    indexed-traversable-0.1.4-6KK4zTGU8Qr6m89IZg6q2E
    lens-5.2.3-J1GK3I4tdtMEzlekK9vBY2
    optics-core-0.4.1.1-EDlpFmfst131UhQUq18TXk
    optics-extra-0.4.2.1-FXTqJtMYdHACumrym2kyHu
    semigroupoids-6.0.1-JHl4aQVyW7mICTCFJ6H2qf text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-Jl6TkouWI2i1D1jczNV0uv

haddock-interfaces:
    /usr/share/doc/haskell-insert-ordered-containers/html/insert-ordered-containers.haddock

haddock-html:         /usr/share/doc/haskell-insert-ordered-containers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
